@@ -1,9 +1,6 @@
-import gi
-
 from cozy.ext import inject
 from cozy.view_model.sleep_timer_view_model import SleepTimerViewModel, SystemPowerControl
 
-gi.require_version('Gtk', '3.0')
 from gi.repository import Gtk
 
 
@@ -21,8 +18,8 @@ class SleepTimer(Gtk.Popover):
 
     power_control_switch: Gtk.Switch = Gtk.Template.Child()
     power_control_options: Gtk.Box = Gtk.Template.Child()
-    system_shutdown_radiob: Gtk.RadioButton = Gtk.Template.Child()
-    system_suspend_radiob: Gtk.RadioButton = Gtk.Template.Child()
+    system_shutdown_radiob: Gtk.CheckButton = Gtk.Template.Child()
+    system_suspend_radiob: Gtk.CheckButton = Gtk.Template.Child()
 
     def __init__(self, timer_image: Gtk.Image):
         super().__init__()
@@ -101,4 +98,5 @@ class SleepTimer(Gtk.Popover):
         else:
             icon = "no-bed-symbolic"
 
-        self._timer_image.set_from_icon_name(icon, Gtk.IconSize.BUTTON)
+        self._timer_image.set_from_icon_name(icon)
+
