@@ -21,12 +21,11 @@ from cozy.open_view import OpenView
 from cozy.ui.app_view import AppView
 from cozy.ui.book_detail_view import BookDetailView
 from cozy.ui.headerbar import Headerbar
-from cozy.ui.info_banner import InfoBanner
+from cozy.ui.toaster import ToastNotifier
 from cozy.ui.library_view import LibraryView
 from cozy.ui.main_view import CozyUI
 from cozy.ui.media_controller import MediaController
 from cozy.ui.search_view import SearchView
-from cozy.ui.widgets.whats_new_window import WhatsNewWindow
 from cozy.view import View
 from cozy.view_model.app_view_model import AppViewModel
 from cozy.view_model.book_detail_view_model import BookDetailViewModel
@@ -37,6 +36,7 @@ from cozy.view_model.playback_speed_view_model import PlaybackSpeedViewModel
 from cozy.view_model.search_view_model import SearchViewModel
 from cozy.view_model.settings_view_model import SettingsViewModel
 from cozy.view_model.sleep_timer_view_model import SleepTimerViewModel
+from cozy.view_model.storages_view_model import StoragesViewModel
 
 
 class AppController(metaclass=Singleton):
@@ -49,14 +49,12 @@ class AppController(metaclass=Singleton):
 
         reporter.info("main", "startup")
 
-        self.whats_new_window: WhatsNewWindow = WhatsNewWindow()
-
         self.library_view: LibraryView = LibraryView(main_window_builder)
         self.app_view: AppView = AppView(main_window_builder)
-        self.search_view: SearchView = SearchView()
-        self.book_detail_view: BookDetailView = BookDetailView(main_window_builder)
         self.headerbar: Headerbar = Headerbar(main_window_builder)
+        self.book_detail_view: BookDetailView = BookDetailView(main_window_builder)
         self.media_controller: MediaController = MediaController(main_window_builder)
+        self.search_view: SearchView = SearchView(main_window_builder, self.headerbar)
 
         self.library_view_model = inject.instance(LibraryViewModel)
         self.app_view_model = inject.instance(AppViewModel)
@@ -68,14 +66,14 @@ class AppController(metaclass=Singleton):
         self.settings_view_model = inject.instance(SettingsViewModel)
         self.player = inject.instance(Player)
 
-        self._connect_popovers()
+        self._connect_search_button()
 
         self.search_view_model.add_listener(self._on_open_view)
         self.book_detail_view_model.add_listener(self._on_open_view)
         self.library_view_model.add_listener(self._on_open_view)
         self.library_view_model.add_listener(self._on_library_view_event)
         self.playback_control_view_model.add_listener(self._on_open_view)
-        self.headerbar_view_model.add_listener(self._on_open_view)
+        self.headerbar_view_model.add_listener(self._on_working_event)
         self.app_view_model.add_listener(self._on_app_view_event)
 
         self.main_window.add_listener(self._on_main_window_event)
@@ -105,9 +103,10 @@ class AppController(metaclass=Singleton):
         binder.bind_to_constructor(SleepTimerViewModel, lambda: SleepTimerViewModel())
         binder.bind_to_constructor(GstPlayer, lambda: GstPlayer())
         binder.bind_to_constructor(PowerManager, lambda: PowerManager())
-        binder.bind_to_constructor(InfoBanner, lambda: InfoBanner())
+        binder.bind_to_constructor(ToastNotifier, lambda: ToastNotifier())
         binder.bind_to_constructor(AppViewModel, lambda: AppViewModel())
         binder.bind_to_constructor(SettingsViewModel, lambda: SettingsViewModel())
+        binder.bind_to_constructor(StoragesViewModel, lambda: StoragesViewModel())
 
     def open_author(self, author: str):
         self.library_view_model.library_view_mode = LibraryViewMode.AUTHOR
@@ -125,11 +124,11 @@ class AppController(metaclass=Singleton):
         self.library_view_model.open_library()
         self.app_view_model.view = View.LIBRARY_FILTER
 
-    def navigate_back(self):
-        self.app_view_model.navigate_back()
-
-    def _connect_popovers(self):
-        self.headerbar.search_button.set_popover(self.search_view.popover)
+    def _connect_search_button(self):
+        self.headerbar.search_button.connect(
+            "notify::active",
+            self.search_view.on_state_changed
+        )
 
     def _on_open_view(self, event, data):
         if event == OpenView.AUTHOR:
@@ -140,8 +139,6 @@ class AppController(metaclass=Singleton):
             self.open_book(data)
         elif event == OpenView.LIBRARY:
             self.open_library()
-        elif event == OpenView.BACK:
-            self.navigate_back()
 
     def _on_library_view_event(self, event: str, _):
         if event == "work-done":
@@ -151,10 +148,12 @@ class AppController(metaclass=Singleton):
         if event == "view":
             self.headerbar_view_model.set_view(data)
 
-    def _on_main_window_event(self, event: str, data):
+    def _on_working_event(self, event: str, data) -> None:
         if event == "working":
             self.book_detail_view_model.lock_ui = data
             self.settings_view_model.lock_ui = data
+
+    def _on_main_window_event(self, event: str, data):
         if event == "open_view":
             self._on_open_view(data, None)
 
